# Installation

You can add **FastAPI Users** to your FastAPI project in a few easy steps. First of all, install the dependency:

## With SQLAlchemy support

```sh
pip install 'fastapi-users[sqlalchemy]'
```


## With Beanie support

```sh
pip install 'fastapi-users[beanie]'
```

## With Redis authentication backend support

Information on installing with proper database support can be found in the [Redis](configuration/authentication/strategies/redis.md) section.

## With OAuth2 support

Information on installing with proper database support can be found in the [OAuth2](configuration/oauth.md) section.


---

That's it! In the next section, we'll have an [overview](./configuration/overview.md) of how things work.
